@@ -22,6 +22,7 @@
 #include <sal/config.h>
 
 #include <cassert>
+#include <cstddef>
 
 #include <rtl/alloc.h>
 
@@ -90,7 +91,7 @@ public:
         @return true if reference acquires an interface, i.e. true if it is not null
     */
     inline bool SAL_CALL is() const
-        { return (0 != _pInterface); }
+        { return (NULL != _pInterface); }
 
     /** Equality operator: compares two interfaces
         Checks if both references are null or refer to the same object.
@@ -181,7 +182,7 @@ private:
 
     struct S { char c[2]; };
 
-#if defined _MSC_VER
+#if defined _MSC_VER && _MSC_VER < 1800
     static char f(T2 *, long);
     static S f(T1 * const &, int);
 #else
@@ -190,8 +191,8 @@ private:
 #endif
 
     struct H {
-        H(); // avoid C2514 "class has no constructors" from MSVC 2008
-#if defined _MSC_VER
+        H(); // avoid C2514 "class has no constructors" from MSVC
+#if defined _MSC_VER && _MSC_VER < 1800
         operator T1 * const & () const;
 #else
         operator T1 * () const;
